#include <Servo.h>  
Servo myservo1;   // create servo object to control a servo
Servo myservo2;   // create servo object to control a servo

int pir = 6;                //PIR sensor pin
int AutoButton = 4;         //auto/manual button pin
int TransButton = 2;        //transition button pin
int pirState = LOW;         //variable to store PIR sensor state
int AutoState = LOW;        //variable to store auto/manual button state
int TransState = LOW;       //variable to store transition button state
int LastTransState = LOW;   //variable to store the previous transition button state
int val = 0;                //variable to store transition button analog read
unsigned long LastDetectTime; //variale to store the time of last movement detection
unsigned long TimeNow;      //variable to store the current time


void setup()                 
{
  pinMode(pir, INPUT);             // initialize the pin mode
  pinMode(AutoButton, INPUT);      // initialize the pin mode
  pinMode(TransButton, INPUT);     // initialize the pin mode
  rotate(myservo1.read(), 45, 90); // set an initial positin for servo upon start up
  myservo1.attach(0);              // attaches the servo on pin 0 to the servo object
  myservo2.attach(1);              // attaches the servo on pin 1 to the servo object
  Serial.begin(9600);
 
}

void loop()
{
  pirState = digitalRead(pir);
  Serial.println(pirState);             // print the PIR state
  AutoState = analogRead(AutoButton);   // recording auto/manual button state
  val = analogRead(TransButton);        
  if (val>=1000) {                      // recording transition button state
    TransState = HIGH;
    } else {
      TransState=LOW;
      }

// CASE 1: auto mode - motion detected:
  if(AutoState>=1000){
    if(pirState==HIGH){
      if(myservo1.read()==45){      // if in cap postion
        rotate(45, 10, 90);         // move to shield position
        delay(500);
      }
    LastDetectTime = millis();     // record the time of last motion detection
    }
  
// CASE 2: auto mode - no motion:  
    if(pirState==LOW){       //PIR remains high after 10sec of last motion detection
      TimeNow = millis();    // current time
      // if at least 10sec has past since the last PIR high state (20sec in total)
      if (TimeNow-LastDetectTime>=10000){  
        if(myservo1.read()==10){  // if in shield position
    rotate(10, 45, 90);           // move to cap position
        delay(500);
        }
      }
    }
  }
  

// CASE 3: manual mode - using transition button:  
  else if (TransState != LastTransState) {   // if the transition button is pressed
    Serial.println("Transition change requested!");
    if(myservo1.read()==45){                 // if in cap postion
       rotate(45, 10, 90);                   // move to shield
      } 
      else {                                 // otherewise
      rotate(10, 45, 90);                    // move to cap
      }
    delay(1000);
    LastTransState = TransState;
  }

}
  


// My function for controling the speed of rotation of servos in reverse directions

void rotate(int from, int to, int speedpercent){
  int pos = 0;
  //delay time between each rotation steps which is represeted as percentage of speed
  int del = (100-speedpercent);    

  if(from<to){
    for (pos=from; pos<=to; pos++) {
      myservo1.write(pos);
       // move the 2nd servo in reverse direction since it is mirrored 
       // (only for moving back and forth from 10 to 45)
       myservo2.write(55-pos);    
      delay(del);
    }
  }

  if(from>to){
    for (pos=from; pos>=to; pos--) {
      myservo1.write(pos);
       // move the 2nd servo in reverse direction since it is mirrored 
       // (only for moving back and forth from 10 to 45)
      myservo2.write(55-pos);    
      delay(del);
    }
  }
}
